@@ -12,7 +12,7 @@ sys.path.insert(0, str(_src_dir))
 
 project = "sphinx-codeautolink"
 author = "Felix Hildén"
-copyright = "2021, Felix Hildén"
+copyright = "2021-2022, Felix Hildén"
 version = Path(_package_root, "sphinx_codeautolink", "VERSION").read_text().strip()
 release = version
 
@@ -25,6 +25,8 @@ extensions = [
     "sphinx_codeautolink",
     "matplotlib.sphinxext.plot_directive",
     "sphinx.ext.doctest",
+    "IPython.sphinxext.ipython_directive",
+    "IPython.sphinxext.ipython_console_highlighting",
 ]
 
 # Builtin options
@@ -41,6 +43,7 @@ autodoc_default_options = {
 }
 autodoc_typehints = "description"
 intersphinx_mapping = {
+    "python": ('https://docs.python.org/3/', None),
     "numpy": ("https://numpy.org/doc/stable/", None),
     "matplotlib": ("https://matplotlib.org/stable/", None),
 }
