@@ -1,20 +1,22 @@
 """Analyse AST of code blocks to determine used names and their sources."""
 import ast
 import sys
+import builtins
 
 from contextlib import contextmanager
 from enum import Enum
 from functools import wraps
 from importlib import import_module
 from typing import Dict, Union, List, Optional, Tuple
-from warnings import warn
 from dataclasses import dataclass, field
 
+from .warn import logger, warn_type
 
-def parse_names(source: str) -> List['Name']:
+
+def parse_names(source: str, doctree_node) -> List['Name']:
     """Parse names from source."""
     tree = ast.parse(source)
-    visitor = ImportTrackerVisitor()
+    visitor = ImportTrackerVisitor(doctree_node)
     visitor.visit(tree)
     return sum([split_access(a) for a in visitor.accessed], [])
 
@@ -201,19 +203,27 @@ def track_parents(func):
     return wrapper
 
 
+builtin_components: Dict[str, List[Component]] = {
+    b: [Component(b, -1, -1, LinkContext.none)] for b in dir(builtins)
+}
+
+
 class ImportTrackerVisitor(ast.NodeVisitor):
     """Track imports and their use through source code."""
 
-    def __init__(self):
+    def __init__(self, doctree_node):
         super().__init__()
         self.accessed: List[Access] = []
         self.in_augassign = False
         self._parents = 0
+        self.doctree_node = doctree_node
 
         # Stack for dealing with class body pseudo scopes
         # which are completely bypassed by inner scopes (func, lambda).
         # Current values are copied to the next class body level.
-        self.pseudo_scopes_stack: List[Dict[str, List[Component]]] = [{}]
+        self.pseudo_scopes_stack: List[Dict[str, List[Component]]] = [
+            builtin_components.copy()
+        ]
         # Stack for dealing with nested scopes.
         # Holds references to the values of previous nesting levels.
         self.outer_scopes_stack: List[Dict[str, List[Component]]] = []
@@ -348,7 +358,12 @@ class ImportTrackerVisitor(ast.NodeVisitor):
                 ]
                 aliases = [None] * len(import_names)
             except ImportError:
-                warn(f'Could not import module `{node.module}` for parsing!')
+                logger.warning(
+                    f'Could not import module `{node.module}` for parsing!',
+                    type=warn_type,
+                    subtype='import_star',
+                    location=self.doctree_node,
+                )
                 import_names = []
                 aliases = []
         else:
@@ -526,7 +541,7 @@ class ImportTrackerVisitor(ast.NodeVisitor):
                 continue
             self.visit(arg.annotation)
 
-        inner = self.__class__()
+        inner = self.__class__(self.doctree_node)
         inner.pseudo_scopes_stack[0] = self.pseudo_scopes_stack[0].copy()
         inner.outer_scopes_stack = list(self.outer_scopes_stack)
         inner.outer_scopes_stack.append(self.pseudo_scopes_stack[0])
@@ -547,7 +562,7 @@ class ImportTrackerVisitor(ast.NodeVisitor):
         args = self._get_args(node.args)
         args += [node.args.vararg, node.args.kwarg]
 
-        inner = self.__class__()
+        inner = self.__class__(self.doctree_node)
         inner.pseudo_scopes_stack[0] = self.pseudo_scopes_stack[0].copy()
         for arg in args:
             if arg is None:
@@ -583,7 +598,7 @@ class ImportTrackerVisitor(ast.NodeVisitor):
         self, values: List[ast.AST], generators: List[ast.comprehension]
     ):
         """Separate inner scope, respects class body scope."""
-        inner = self.__class__()
+        inner = self.__class__(self.doctree_node)
         inner.pseudo_scopes_stack[0] = self.pseudo_scopes_stack[-1].copy()
         for gen in generators:
             inner.visit(gen)
